[![tests](https://github.com/VirusTotal/yara-x/actions/workflows/tests.yaml/badge.svg)](https://github.com/VirusTotal/yara-x/actions/workflows/tests.yaml)
[![coverage](https://codecov.io/gh/VirusTotal/yara-x/branch/main/graph/badge.svg?token=dPsruCiDqN)](https://app.codecov.io/gh/VirusTotal/yara-x)
[![Crates.io](https://img.shields.io/crates/v/yara-x.svg)](https://crates.io/crates/yara-x)
![Crates.io MSRV](https://img.shields.io/crates/msrv/yara-x)

## YARA-X

YARA-X is a re-incarnation of [YARA](https://github.com/VirusTotal/yara), a
pattern matching tool designed with malware researchers in mind. This new
incarnation intends to be faster, safer and more user-friendly than its
predecessor. The ultimate goal of YARA-X is to serve as the future replacement
for YARA.

News are coming, stay tuned!